%define major     %{version}
%define libname   %mklibname cmark %{major}
%define develname %mklibname cmark -d

Name:           cmark
Version:        0.31.1
Release:        %mkrel 1
Summary:        CommonMark parsing and rendering
Group:          Development/C

License:        BSD and MIT
URL:            https://github.com/jgm/cmark
Source0:        https://github.com/jgm/cmark/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  gcc-c++

%description
`cmark` is the C reference implementation of CommonMark,
a rationalized version of Markdown syntax with a spec.

It provides a shared library (`libcmark`) with functions for parsing
CommonMark documents to an abstract syntax tree (AST), manipulating
the AST, and rendering the document to HTML, groff man, LaTeX,
CommonMark, or an XML representation of the AST.  It also provides a
command-line program (`cmark`) for parsing and rendering CommonMark
documents.


%package -n %{develname}
Summary:        Development files for cmark
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}


%description -n %{develname}
This package provides the development files for cmark.


%package -n %{libname}
Summary:        CommonMark parsing and rendering library
Group:          System/Libraries
Obsoletes:      %{_lib}cmark0 < 0.30.2-4

%description -n %{libname}
This package provides the cmark library.


%prep
%setup -q


%build
%cmake \
  -DCMARK_STATIC:BOOL=OFF \
  -DCMARK_TESTS:BOOL=OFF
%cmake_build


%install
%cmake_install

%if %{with tests}
%check
%ctest
%endif

%files
%license COPYING
%{_bindir}/cmark
%{_mandir}/man1/cmark.1.*


%files -n %{libname}
%license COPYING
%{_libdir}/libcmark.so.%{version}


%files -n %{develname}
%doc README.md
%{_includedir}/cmark.h
%{_includedir}/cmark_export.h
%{_includedir}/cmark_version.h
%{_libdir}/libcmark.so
%{_libdir}/pkgconfig/libcmark.pc
%{_mandir}/man3/cmark.3.*
%{_libdir}/cmake/cmark/


%changelog
* Tue Aug 13 2024 daviddavid <daviddavid> 0.31.1-1.mga10
+ Revision: 2086553
- new version: 0.31.1

* Sun Mar 10 2024 daviddavid <daviddavid> 0.31.0-1.mga10
+ Revision: 2049051
- new version: 0.31.0

* Sun May 21 2023 daviddavid <daviddavid> 0.30.3-2.mga9
+ Revision: 1957633
- add virtual provides in devel sub-pkg

* Sat Feb 11 2023 mrambo3501 <mrambo3501> 0.30.3-1.mga9
+ Revision: 1940766
- version 0.30.3

* Sun Apr 03 2022 wally <wally> 0.30.2-4.mga9
+ Revision: 1842672
- fix lib pkg name
- disable static build

* Thu Mar 17 2022 umeabot <umeabot> 0.30.2-3.mga9
+ Revision: 1796845
- Mageia 9 Mass Rebuild

* Fri Jan 28 2022 neoclust <neoclust> 0.30.2-2.mga9
+ Revision: 1770161
- Make the devel package require main package

* Fri Jan 14 2022 mrambo3501 <mrambo3501> 0.30.2-1.mga9
+ Revision: 1768325
- version 0.30.2

* Thu Feb 20 2020 umeabot <umeabot> 0.29.0-2.mga8
+ Revision: 1546225
- Mageia 8 Mass Rebuild

* Sat Feb 01 2020 daviddavid <daviddavid> 0.29.0-1.mga8
+ Revision: 1486192
- new version: 0.29.0
+ wally <wally>
- build with new cmake macros

* Sat Sep 22 2018 umeabot <umeabot> 0.28.3-2.mga7
+ Revision: 1296618
- Mageia 7 Mass Rebuild

* Sun Feb 25 2018 shlomif <shlomif> 0.28.3-1.mga7
+ Revision: 1205156
- Fix libname dep
- Importing based on Fedora


* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.28.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Dec 11 2017 Jens Petersen <petersen@redhat.com> - 0.28.3-1
- update to 0.28.3 (#1516914)
  https://github.com/commonmark/cmark/releases

* Sun Aug 06 2017 Björn Esser <besser82@fedoraproject.org> - 0.27.1-4
- Rebuilt for AutoReq cmake-filesystem

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.27.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.27.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Feb 22 2017 Jens Petersen <petersen@redhat.com> - 0.27.1-1
- update to 0.27.1

* Tue Feb  7 2017 Jens Petersen <petersen@redhat.com> - 0.25.2-3
- drop lib64 patch

* Sun Feb  5 2017 Jens Petersen <petersen@redhat.com> - 0.25.2-2
- fix libdir in libcmark.pc for pkgconf (#1416426)
- use bcond for tests

* Fri Apr 29 2016 John Dulaney <jdulaney@fedoraproject.org> - 0.25.2-1
- Update to 0.25.2

* Thu Feb  4 2016 Jens Petersen <petersen@redhat.com> - 0.24.1-1
- update to 0.24.1

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.23.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jan 28 2016 Jens Petersen <petersen@redhat.com> - 0.23.0-4
- BR c++ explicitly
- disable tests for EPEL6 since no python3

* Mon Jan 25 2016 Jens Petersen <petersen@redhat.com> - 0.23.0-3
- include license in lib (#1266429)

* Thu Jan 21 2016 Jens Petersen <petersen@redhat.com> - 0.23.0-2
- tweak the github release source url (#1266429)

* Wed Jan 20 2016 Jens Petersen <petersen@redhat.com> - 0.23.0-1
- update to 0.23.0
- cmake include GNUInstallDirs (Marco Driusso, #1266429)

* Fri Sep 25 2015 Jens Petersen <petersen@redhat.com> - 0.22.0-1
- initial packaging
- force lib64
- run tests
